package com.zswl.cloud.springBtach.server.core.job.video2;

import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.eeext.openapi.entity.RechargeOrderReq;
import com.github.microservice.auth.client.content.ResultContent;
import com.github.microservice.auth.client.content.ResultState;
import com.zhongshu.payment.client.model.order.v2.GoodsResultModel;
import com.zhongshu.payment.client.service.v2.OrderService2;
import com.zhongshu.payment.client.service.v2.PaymentService2;
import com.zswl.cloud.shop.client.service.GoodsService;
import com.zswl.cloud.shop.client.service.ShopService;
import com.zswl.cloud.springBtach.server.core.api.video2.Video2Api;
import com.zswl.cloud.springBtach.server.core.job.standard.StandarDeliveryJob;
import lombok.Data;
import lombok.experimental.Delegate;
import lombok.extern.log4j.Log4j2;
import org.springframework.batch.core.Job;
import org.springframework.batch.core.Step;
import org.springframework.batch.core.launch.support.RunIdIncrementer;
import org.springframework.batch.repeat.RepeatStatus;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

@Data
@Log4j2
@Configuration
public class Video2DeliveryJob {

    @Autowired
    @Delegate
    StandarDeliveryJob standarDeliveryJob;

    @Autowired
    GoodsService goodsService;

    @Autowired
    OrderService2 orderService2;

    @Autowired
    PaymentService2 paymentService2;

    @Autowired
    ShopService shopService;

    @Autowired
    Video2Api video2Api;

    @Value("${video2.notifyUrl}")
    private String notifyUrl;


    public Step video2DeliveryStep() {
        return getStepBuilderFactory().get("video2DeliveryStep")
                .tasklet((contribution, chunkContext) -> {
                    GoodsResultModel goodsResultModel = getParameter().get();


                    JSONObject goodsInfo = goodsResultModel.getGoodsInfo();
                    RechargeOrderReq rechargeOrderReq = JSONUtil.toBean(goodsInfo, RechargeOrderReq.class);
                    rechargeOrderReq.setOutTradeNo(goodsResultModel.getOrderNo());
                    rechargeOrderReq.setNotifyUrl(notifyUrl);
                    video2Api.rechargeOrder(rechargeOrderReq);

                    getResultContent().set(ResultContent.build(ResultState.Success));
                    return RepeatStatus.FINISHED;

                })
                .build();
    }

    @Bean
    public Job video2Delivery() {
        return getJobBuilderFactory()
                .get("video2Delivery")
                .start(video2DeliveryStep())
                .incrementer(new RunIdIncrementer())
                .build();
    }

}

